@@ -3,8 +3,8 @@ OC.L10N.register(
     {
     "Notes" : "Notes",
     "Error" : "Памылка",
-    "Settings" : "Налады",
     "Today" : "Today",
+    "Yesterday" : "Учора",
     "Rename" : "Rename",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites"
