@@ -5,8 +5,11 @@ OC.L10N.register(
     "Error" : "Fejl",
     "New note" : "Ny note",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Der er noter der ikke er gemt. Hvis du forlader denne side vil de blive smidt væk!",
-    "Settings" : "Indstillinger",
+    "Display mode for notes" : "Visningstilstand for noter",
+    "Open in edit mode" : "Åbn i redigeringstilstand",
+    "Open in preview mode" : "Åbn forhåndsvisning",
     "No notes yet" : "Ingen noter endnu",
+    "Insert image" : "Indsæt billede",
     "All notes" : "Alle noter",
     "Categories" : "Kategorier",
     "Loading …" : "Indlæser…",
@@ -20,6 +23,7 @@ OC.L10N.register(
     "Delete note" : "Slet note",
     "Remove from favorites" : "Fjernet fra favoritter",
     "Add to favorites" : "Føj til favoritter",
+    "Use current version" : "Brug aktuelle version",
     "Details" : "Detaljer",
     "Edit" : "Redigér",
     "Preview" : "Vis eksempel",
