@@ -6,10 +6,9 @@ OC.L10N.register(
     "New note" : "Nova noto",
     "Distraction-free notes and writing" : "Sendistraj notoj kaj skribado",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Estas nekonservitaj notoj. Foriro el la paĝo perdos ĉiujn ŝanĝojn!",
-    "Settings" : "Agordoj",
     "Folder to store your notes" : "Dosiero, en kiu konservi viajn notojn",
-    "path to notes" : "vojo al notoj",
     "File extension for new notes" : "Dosiersufikso por novaj notoj",
+    "Insert image" : "Enmeti bildon",
     "All notes" : "Ĉiuj notoj",
     "Categories" : "Kategorioj",
     "Loading …" : "Ŝargado...",
@@ -19,6 +18,7 @@ OC.L10N.register(
     "Delete note" : "Forigi noton",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
     "Add to favorites" : "Aldoni al pliŝataĵoj",
+    "Use current version" : "Uzi nunan version",
     "Details" : "Detaloj",
     "Edit" : "Modifi",
     "Preview" : "Antaŭvidi",
