@@ -2,6 +2,7 @@ OC.L10N.register(
     "notes",
     {
     "Notes" : "Užrašai",
+    "Reading notes from filesystem has failed." : "Nepavyko perskaityti užrašų iš failų sistemos.",
     "Error" : "Klaida",
     "New note" : "Nauji užrašai",
     "Distraction-free notes and writing" : "Neblaškantys užrašai ir rašymas",
@@ -9,13 +10,19 @@ OC.L10N.register(
     "Deleted {title}" : "{title} ištrinti",
     "Undo Delete" : "Atšaukti ištrynimą",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Yra neįrašytų užrašų. Išėjus iš šio puslapio, visi pakeitimai bus atmesti!",
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["Ištrinti {number} užrašai","Ištrinti {number} užrašai","Ištrinta {number} užrašų","Ištrinti {number} užrašai"],
+    "_Recovered {number} note_::_Recovered {number} notes_" : ["Atkurti {number} užrašai","Atkurti {number} užrašai","Atkurta {number} užrašų","Atkurti {number} užrašai"],
+    "Notes settings" : "Užrašų nustatymai",
     "Folder to store your notes" : "Aplankas, kuriame saugoti jūsų užrašus",
     "File extension for new notes" : "Naujų užrašų failo prievardis",
     "Display mode for notes" : "Užrašų rodinio veiksena",
+    "User defined" : "Naudotojo apibrėžtas",
     "Open in edit mode" : "Atverti redagavimo veiksenoje",
     "Open in preview mode" : "Atverti peržiūros veiksenoje",
-    "No notes yet" : "Nėra užrašų",
+    "No notes yet" : "Kol kas užrašų nėra",
     "Insert image" : "Įterpti paveikslą",
+    "Select an image" : "Pasirinkite paveikslą",
+    "Wrong image" : "Neteisingas paveikslas",
     "All notes" : "Visi užrašai",
     "Categories" : "Kategorijos",
     "Loading …" : "Įkeliama…",
@@ -26,9 +33,11 @@ OC.L10N.register(
     "This month" : "Šį mėnesį",
     "Last month" : "Praeitą mėnesį",
     "Rename" : "Pervadinti",
+    "Note's title" : "Užrašų pavadinimas",
     "Delete note" : "Ištrinti užrašus",
     "Remove from favorites" : "Šalinti iš mėgstamų",
     "Add to favorites" : "Pridėti į mėgstamus",
+    "Use version from server" : "Naudoti versiją iš serverio",
     "Use current version" : "Naudoti esamą versiją",
     "Empty note" : "Tušti užrašai",
     "Write …" : "Rašykite…",
@@ -37,7 +46,9 @@ OC.L10N.register(
     "Preview" : "Peržiūra",
     "Exit full screen" : "Išeiti iš viso ekrano",
     "Full screen" : "Visas ekranas",
+    "Note is read-only. You cannot change it." : "Užrašai yra tik skaitymui. Jūs negalite jų keisti.",
     "Save failed. Click to retry." : "Nepavyko įrašyti. Spustelėkite, norėdami bandyti dar kartą.",
+    "Error from Nextcloud server: {msg}" : "Klaida iš Nextcloud serverio: {msg}",
     "Set category" : "Nustatyti kategoriją",
     "Category" : "Kategorija",
     "Uncategorized" : "Nekategorizuoti",
@@ -47,10 +58,17 @@ OC.L10N.register(
     "Note has unsaved changes" : "Užrašuose yra neįrašytų pakeitimų.",
     "Subcategory" : "Subkategorija",
     "_%n word_::_%n words_" : ["%n žodis","%n žodžiai","%n žodžių","%n žodis"],
+    "_%n character_::_%n characters_" : ["%n simbolis","%n simboliai","%n simbolių","%n simbolis"],
     "Write down your thoughts without any distractions." : "Užsirašykite savo mintis be jokio blaškymosi.",
-    "Android app" : "Android programėlė",
-    "iOS app" : "iOS programėlė",
+    "Use Markdown markups to style your text." : "Naudokite „Markdown“ ženklinimo kalbą, kad taisytumėte teksto stilių.",
+    "Organize your notes in categories." : "Skirstykite užrašus po kategorijas.",
+    "Install the app for your mobile phone in order to access your notes from everywhere." : "Įsidiekite programėlę mobiliajame telefone, kad visur turėtumėte prieigą prie savo užrašų.",
+    "Android app" : "„Android“ programėlė",
+    "iOS app" : "„iOS“ programėlė",
+    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Pradėkite rašyti užrašus, spusteldami ant mygtuko „{newnote}“.",
     "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Galite sukurti subkategorijas, naudodami \"/\" kaip skirtuką tarp viršesnės kategorijos ir subkategorijos, pvz., “{parent}/{sub}”.",
+    "Note not found." : "Užrašai nerasti.",
+    "Note is locked." : "Užrašai užrakinti.",
     "Updating settings has failed." : "Nepavyko atnaujinti nustatymų.",
     "Updating the note's category has failed. Is the target directory writable?" : "Nepavyko atnaujinti užrašų kategorijos. Ar paskirties katalogas yra skirtas rašymui?",
     "Development Mode" : "Plėtotojo veiksena"
