@@ -4,7 +4,8 @@ OC.L10N.register(
     "Notes" : "Shënime",
     "Error" : "Error",
     "New note" : "Shënim i ri",
-    "Settings" : "Rregullimet",
+    "Open in edit mode" : "Hapur në modalitetin e redaktimit",
+    "Open in preview mode" : "Hape në parapamje",
     "No notes yet" : "Nuk ka shënime",
     "All notes" : "Të gjitha shënimet",
     "Categories" : "Kategoritë",
@@ -16,6 +17,7 @@ OC.L10N.register(
     "Delete note" : "Fshije shënimin",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Shtoje tek të parapëlqyerat",
+    "Use current version" : "Përdor versionin aktual",
     "Details" : "Detajet",
     "Edit" : "Përpuno",
     "Preview" : "Parapamje ",
