@@ -3,8 +3,8 @@ OC.L10N.register(
     {
     "Notes" : "குறிப்புகள்",
     "Error" : "வழு",
-    "Settings" : "அமைப்புகள்",
     "Today" : "இன்று",
+    "Yesterday" : "நேற்று",
     "Rename" : "பெயர்மாற்றம்",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
